Learn R Programming

mycaas (version 0.0.1)

summary.assessment: Summary (Method)

Description

Function used to produce result summaries of an assessment object.

Usage

# S3 method for assessment
summary(object, ...)

Value

The function return a summary of the information in the a assessment object

Arguments

object

Assessment object to display

...

Additional arguments affecting the summary produced.

Examples

Run this code
#   Example of random items presentation

token<- assessment(N_items = 5 ,adaptive = FALSE, ki=15)
summary(token)

Run the code above in your browser using DataLab