powered by
Function used to produce result summaries of an assessment object.
# S3 method for assessment summary(object, ...)
The function return a summary of the information in the a assessment object
Assessment object to display
Additional arguments affecting the summary produced.
# Example of random items presentation token<- assessment(N_items = 5 ,adaptive = FALSE, ki=15) summary(token)
Run the code above in your browser using DataLab